import sys
import math
import random

num_points = int(sys.argv[1])
num_lines = int(sys.argv[2])
num_triangles = int(sys.argv[3])
num_degenerates = int(sys.argv[4])
max_coord = int(sys.argv[5])

allow_overlaps = num_degenerates > 0

random.seed(num_points + num_lines + num_triangles + num_degenerates + max_coord)

points = set()
while len(points) < num_points:
	points.add((random.randint(-max_coord, max_coord), random.randint(-max_coord, max_coord)))
points = list(points)

def crossprod(p0, p1, p2):
	return (p0[0] - p1[0]) * (p0[1] - p2[1]) - (p0[0] - p2[0]) * (p0[1] - p1[1])

def dotprod(p0, p1, p2):
	return (p0[0] - p1[0]) * (p0[0] - p2[0]) + (p0[1] - p1[1]) * (p0[1] - p2[1])

def overlap(l1, l2):
	if crossprod(l1[0], l1[1], l2[0]) != 0:
		return False
	if crossprod(l1[0], l1[1], l2[1]) != 0:
		return False
	if dotprod(l1[0], l2[0], l2[1]) < 0:
		return True
	if dotprod(l1[1], l2[0], l2[1]) < 0:
		return True
	if dotprod(l2[0], l1[0], l1[1]) < 0:
		return True
	if dotprod(l2[1], l1[0], l1[1]) < 0:
		return True
	return False

lines = set()

while num_triangles > 0:
	p1, p2, p3 = random.sample(points, 3)
	overlaps = [x for x in lines if overlap((p1, p2), x) or overlap((p2, p3), x) or overlap((p3, p1), x)]
	if not allow_overlaps and len(overlaps) > 0:
		continue
	lines.add((min(p1, p2), max(p1, p2)))
	lines.add((min(p2, p3), max(p2, p3)))
	lines.add((min(p3, p1), max(p3, p1)))
	num_triangles -= 1

while num_degenerates > 0:
	p1, p2 = random.sample(points, 2)
	dx, dy = p2[0] - p1[0], p2[1] - p1[1]
	d = math.gcd(abs(dx), abs(dy))
	if d == 1:
		continue
	i = random.randint(1, d - 1)
	p3 = (p1[0] + dx // d * i, p1[1] + dy // d * i)
	lines.add((min(p1, p2), max(p1, p2)))
	lines.add((min(p2, p3), max(p2, p3)))
	lines.add((min(p3, p1), max(p3, p1)))
	num_degenerates -= 1

while len(lines) < num_lines:
	p1, p2 = random.sample(points, 2)
	overlaps = [x for x in lines if overlap((p1, p2), x)]
	if not allow_overlaps and len(overlaps) > 0:
		continue
	lines.add((min(p1, p2), max(p1, p2)))

lines = list(lines)
random.shuffle(lines)

assert len(lines) <= num_lines

print(len(lines))
for x in lines:
	i = random.randint(0, 1)
	print(x[i][0], x[i][1], x[1 - i][0], x[1 - i][1])
