// efektiivne lahendus lõigupaaride läbivaatusega:
// kontrollib iga kahe lõigu jaoks, kas leidub ka
// kolmas, mis nendega kokku kolmnurga moodustab

// kasutab set andmetüüpi, millesse elementide lisamise
// ja nende sealt otsimise aeg on logaritmiline;
// lahenduse kogukeerukus on seega O(N^2 * log(N))

// osaline lahendus, püüab lõikude kattumisi kontrollida
// nende pikkuste võrdlemisega ja saab osades testides
// ujukomaarvude ümardamisvigade pärast valed vastused

// see variant kasutab topelttäpsusega reaalarve

#include <iostream>
#include <algorithm>
#include <set>
#include <cmath>
using namespace std;

struct punkt { int x, y; };

// punktide võrdlusoperaatorid
bool operator==(punkt const& p1, punkt const& p2) {
	return p1.x == p2.x and p1.y == p2.y;
}
bool operator<(punkt const& p1, punkt const& p2) {
	return p1.x < p2.x or p1.x == p2.x and p1.y < p2.y;
}

struct loik { punkt a, b; };

// lõikude võrdlusoperaator, set vajab seda
bool operator<(loik const& l1, loik const& l2) {
	return l1.a < l2.a or l1.a == l2.a and l1.b < l2.b;
}

// leiab lõigu pikkuse
double pikkus(loik const& l) {
	int dx = l.a.x - l.b.x;
	int dy = l.a.y - l.b.y;
	return sqrt(dx * dx + dy * dy);
}

int main() {
	int n;
	cin >> n;
	set<loik> ll;
	for (int i = 0; i < n; ++i) {
		punkt p1, p2;
		cin >> p1.x >> p1.y >> p2.x >> p2.y;
		ll.insert(loik({min(p1, p2), max(p1, p2)}));
	}

	int m = 0;
	for (auto const& l1 : ll) {
		for (auto const& l2 : ll) {
			if (!(l1.a == l2.a)) {
				// need kaks lõiku ei moodusta vasakut alumist nurka
				continue;
			}
			loik lx{min(l1.b, l2.b), max(l1.b, l2.b)};
			if (ll.count(lx) == 0) {
				// kolmandat serva ei ole
				continue;
			}
			// kontrollime, et kolmnurk ei ole kõdunud:
			// pikima külje pikkus peab olema rangelt väiksem kui
			// lühemate külgede pikkuste summa
			auto p1 = pikkus(l1), p2 = pikkus(l2), p3 = pikkus(lx);
			if (2 * max(p1, max(p2, p3)) < p1 + p2 + p3) {
				m += 1;
			}
		}
	}

	cout << m / 2 << '\n';
}
