// efektiivne lahendus lõigupaaride läbivaatusega:
// kontrollib iga kahe lõigu jaoks, kas leidub ka
// kolmas, mis nendega kokku kolmnurga moodustab

// kasutab unordered_set andmetüüpi, millesse elementide
// lisamise ja nende sealt otsimise aeg on konstantne;
// lahenduse kogukeerukus on seega O(N^2)

// korrektne lahendus, kontrollib lõikude kattumisi
// täisarvuliste arvutustega vektorkorrutise abil ja
// väldib sellega ujukomaarvude ümardamisvigu

#include <iostream>
#include <algorithm>
#include <unordered_set>
#include <functional>
using namespace std;

struct punkt { int x, y; };

// punktide võrdlusoperaatorid
bool operator==(punkt const& p1, punkt const& p2) {
	return p1.x == p2.x and p1.y == p2.y;
}
bool operator<(punkt const& p1, punkt const& p2) {
	return p1.x < p2.x or p1.x == p2.x and p1.y < p2.y;
}

struct loik { punkt a, b; };

// lõikude võrdlus ja räsimine, unordered_set vajab neid
bool operator==(loik const& l1, loik const& l2) {
	return l1.a == l2.a and l1.b == l2.b;
}
struct rasi {
	size_t operator()(loik const& l) const {
		hash<int> h;
		return h(l.a.x) ^ h(l.a.y) ^ h(l.b.x) ^ h(l.b.y);
	}
};

// arvutab p0->p1 ja p0->p2 vektorkorrutise
int vkorr(punkt const& p0, punkt const& p1, punkt const& p2) {
	int dx1 = p1.x - p0.x, dy1 = p1.y - p0.y;
	int dx2 = p2.x - p0.x, dy2 = p2.y - p0.y;
	return dx1 * dy2 - dx2 * dy1;
}

int main() {
	int n;
	cin >> n;
	unordered_set<loik, rasi> ll;
	for (int i = 0; i < n; ++i) {
		punkt p1, p2;
		cin >> p1.x >> p1.y >> p2.x >> p2.y;
		ll.insert(loik({min(p1, p2), max(p1, p2)}));
	}

	int m = 0;
	for (auto const& l1 : ll) {
		for (auto const& l2 : ll) {
			if (!(l1.a == l2.a)) {
				// need kaks lõiku ei moodusta vasakut alumist nurka
				continue;
			}
			loik lx{min(l1.b, l2.b), max(l1.b, l2.b)};
			if (ll.count(lx) == 0) {
				// kolmandat serva ei ole
				continue;
			}
			if (vkorr(l1.a, l1.b, l2.b) == 0) {
				// punktid on ühel sirgel, kolmnurk on kõdunud
				continue;
			}
			m += 1;
		}
	}

	cout << m / 2 << '\n';
}
