// efektiivne lahendus lõigupaaride läbivaatusega:
// kontrollib iga kahe lõigu jaoks, kas leidub ka
// kolmas, mis nendega kokku kolmnurga moodustab

// kasutab vector andmetüüpi; töö kiirendamiseks
// sorterib selle ja rakendab siis kahendotsingut;
// lahenduse kogukeerukus on seega O(N^2 * log(N));
// samas on kasutatavad operatsioonid väga odavad
// ja praktikas on see parima tööajaga lahendus

// korrektne lahendus, kontrollib lõikude kattumisi
// täisarvuliste arvutustega vektorkorrutise abil ja
// väldib sellega ujukomaarvude ümardamisvigu

#include <iostream>
#include <algorithm>
#include <vector>
using namespace std;

struct punkt { int x, y; };

// punktide võrdlusoperaatorid
bool operator==(punkt const& p1, punkt const& p2) {
	return p1.x == p2.x and p1.y == p2.y;
}
bool operator<(punkt const& p1, punkt const& p2) {
	return p1.x < p2.x or p1.x == p2.x and p1.y < p2.y;
}

struct loik { punkt a, b; };

// lõikude võrdlusoperaatorid
bool operator==(loik const& l1, loik const& l2) {
	return l1.a == l2.a and l1.b == l2.b;
}
bool operator<(loik const& l1, loik const& l2) {
	return l1.a < l2.a or l1.a == l2.a and l1.b < l2.b;
}

// arvutab p0->p1 ja p0->p2 vektorkorrutise
int vkorr(punkt const& p0, punkt const& p1, punkt const& p2) {
	int dx1 = p1.x - p0.x, dy1 = p1.y - p0.y;
	int dx2 = p2.x - p0.x, dy2 = p2.y - p0.y;
	return dx1 * dy2 - dx2 * dy1;
}

int main() {
	int n;
	cin >> n;
	vector<loik> ll(n);
	for (auto & l : ll) {
		cin >> l.a.x >> l.a.y >> l.b.x >> l.b.y;
		if (!(l.a < l.b)) swap(l.a, l.b);
	}
	sort(ll.begin(), ll.end());

	int m = 0;
	for (auto const& l1 : ll) {
		for (auto const& l2 : ll) {
			if (!(l1.a == l2.a)) {
				// need kaks lõiku ei moodusta vasakut alumist nurka
				continue;
			}
			loik lx{min(l1.b, l2.b), max(l1.b, l2.b)};
			auto it = lower_bound(ll.begin(), ll.end(), lx);
			if (it == ll.end() or !(*it == lx)) {
				// kolmandat serva ei ole
				continue;
			}
			if (vkorr(l1.a, l1.b, l2.b) == 0) {
				// punktid on ühel sirgel, kolmnurk on kõdunud
				continue;
			}
			m += 1;
		}
	}

	cout << m / 2 << '\n';
}
