import sys

INF = int(1e9 + 5)

class Segtree:
    def __init__ (self, _n):
        self.n = 1
        while self.n < _n:
            self.n *= 2

        self.tree = 2 * self.n * [INF]
        self.lfend = 2 * self.n * [0]
        self.rgend = 2 * self.n * [0]
        for i in range(self.n, 2 * self.n):
            self.lfend[i] = i - self.n
            self.rgend[i] = i - self.n
        for i in range(self.n - 1, 0, -1):
            self.lfend[i] = self.lfend[2 * i]
            self.rgend[i] = self.rgend[2 * i + 1]

    def set (self, pos, val):
        self.tree[self.n + pos] = val
        u = (self.n + pos) // 2
        while u != 0:
            self.tree[u] = min(self.tree[2 * u], self.tree[2 * u + 1])
            u //= 2
            
    def query (self, ql, qr, u = 1):
        ql = max(ql, self.lfend[u])
        qr = min(qr, self.rgend[u])

        if ql > qr:
            return INF
        if ql == self.lfend[u] and qr == self.rgend[u]:
            return self.tree[u]
        return min(self.query(ql, qr, 2 * u), self.query(ql, qr, 2 * u + 1))

n, qc = map(int, sys.stdin.readline().split())
s = sys.stdin.readline().strip()

balance = [0 for i in range(n + 1)]
for i in range(n):
    if s[i] == '(':
        balance[i + 1] = 1 + balance[i]
    else:
        balance[i + 1] = -1 + balance[i]
        
tree = Segtree(n + 1)
for i in range(n + 1):
    tree.set(i, balance[i])

for i in range(qc):
    l, r = map(int, sys.stdin.readline().split())

    if balance[l - 1] != balance[r]:
        sys.stdout.write("EI\n")
    else:
        segmin = tree.query(l, r - 1)
        if segmin == balance[l - 1]:
            sys.stdout.write("JAH\n")
        else:
            sys.stdout.write("EI\n")
