#include <iostream>
#include <vector>

using namespace std;

const int INF = 1e9 + 5;

class Segtree {
  int n;
  vector<int> lfend;
  vector<int> rgend;
  vector<int> tree;
  
public:
  Segtree (int _n) {
    n = 1;
    while (n < _n) {
      n *= 2;
    }

    tree = vector<int> (2 * n, INF);
    lfend = vector<int> (2 * n);
    rgend = vector<int> (2 * n);
    for (int i = n; i < 2 * n; i++) {
      lfend[i] = i - n;
      rgend[i] = i - n;
    }

    for (int i = n - 1; i > 0; i--) {
      lfend[i] = lfend[2 * i];
      rgend[i] = rgend[2 * i + 1];
    }
  }

  void set (int pos, int val) {
    tree[n + pos] = val;
    for (int u = (n + pos) / 2; u != 0; u /= 2) {
      tree[u] = min(tree[2 * u], tree[2 * u + 1]);
    }
  }

  int query (int ql, int qr, int u = 1) {
    ql = max(ql, lfend[u]);
    qr = min(qr, rgend[u]);

    if (ql > qr) return INF;
    if (ql == lfend[u] && qr == rgend[u]) return tree[u];
    return min(query(ql, qr, 2 * u), query(ql, qr, 2 * u + 1));
  }
};

int main () {
  ios::sync_with_stdio(false);
  cin.tie(0);

  int n, qc;
  cin >> n >> qc;

  string s;
  cin >> s;

  vector<int> balance (n + 1, 0);
  for (int i = 1; i <= n; i++) {
    if (s[i - 1] == '(') {
      balance[i] = 1 + balance[i - 1];
    } else {
      balance[i] = -1 + balance[i - 1];
    }
  }

  Segtree tree (n + 1);
  for (int i = 0; i <= n; i++) {
    tree.set(i, balance[i]);
  }

  for (int i = 0; i < qc; i++) {
    int l, r;
    cin >> l >> r;

    if (balance[l - 1] != balance[r]) {
      cout << "EI" << '\n';
    } else if (tree.query(l, r - 1) >= balance[l - 1]) {
      cout << "JAH" << '\n';
    } else {
      cout << "EI" << '\n';
    }
  }
}
